@@ -48,5 +48,3 @@ class Zotero2Readwise:
             self.zotero.save_failed_items_to_json("failed_zotero_items.json")
 
         self.readwise.post_zotero_annotations_to_readwise(formatted_items)
-        if self.readwise.failed_highlights:
-            self.readwise.save_failed_items_to_json("failed_readwise_highlights.json")
